#include <array>
#include "raylib.h"
#include "raymath.h"
#include "Tree.hpp"
#include "Math.hpp"

#define MAX_TREES 2

int main(void)
{
  char name[] = "treender";
  int screenWidth = 800;
  int screenHeight = 800;

#ifdef MY_ANDROID
  InitWindow(0, 0, name);
  screenWidth = GetScreenWidth();
  screenHeight = GetScreenHeight();
#else
  InitWindow(screenWidth, screenHeight, name);
#endif
  SetTargetFPS(60);
  {
    std::array<Tree, MAX_TREES> trees = {Tree(screenWidth), Tree(screenWidth)};

    for (auto &&tree : trees)
      tree.newTree();
    int pos = 0;

    Vector2 center = {(float)screenWidth / 2, (float)screenHeight / 2};
    float rotation = 0.0f;
    Rectangle destA = CalculateRect(center, rotation, screenWidth, screenWidth);
    Rectangle destB = {destA.x, destA.y, (float)screenWidth, (float)screenWidth};

    while (!WindowShouldClose())
    {
      if (IsMouseButtonDown(MOUSE_BUTTON_LEFT))
      {
        int mouseX = GetMouseX();
        center.x = mouseX;
        center.y = GetMouseY();
        float l = (float)mouseX / screenWidth;
        rotation = Lerp(45.0f, -45.0f, l);
        destA = CalculateRect(center, rotation, screenWidth, screenWidth);
      }

      if (IsMouseButtonReleased(MOUSE_BUTTON_LEFT))
      {
        trees[1 - pos].newTree();
        pos = 1 - pos;
        rotation = 0.0f;
        center.x = screenWidth / 2;
        center.y = screenHeight / 2;
        destA = CalculateRect(center, rotation, screenWidth, screenWidth);
      }
      BeginDrawing();
      ClearBackground(RED);
      trees[pos].draw(destB, 0.0f);
      trees[1 - pos].draw(destA, rotation);
      EndDrawing();
    }
  }

  CloseWindow();
  return 0;
}